@@ -14,6 +14,7 @@ class Ticket:
             seat,
             qr_code_url,
             title,
+            legacy_external_event_id,
             external_event_id,
             barcode,
             sector_name,
@@ -53,7 +54,8 @@ class Ticket:
             ticket_auth=None,
             event_date=None,
             currency=None,
-            external_card_ref=None
+            external_card_ref=None,
+            additional_fields=None
     ):
         self.id = id
         self.external_ticket_id = external_ticket_id
@@ -62,6 +64,7 @@ class Ticket:
         self.qr_code_url = qr_code_url
         self.session_date = session_date
         self.title = title
+        self.legacy_external_event_id = legacy_external_event_id
         self.external_event_id = external_event_id
         self.barcode = barcode
         self.sector_name = sector_name
@@ -159,6 +162,7 @@ class Ticket:
                 self.currency = Currency(**currency)
         else:
             self.currency = None
+        self.additional_fields = additional_fields
 
     @classmethod
     def placeholder(
@@ -172,6 +176,7 @@ class Ticket:
             seat=None,
             qr_code_url=None,
             title=None,
+            legacy_external_event_id=None,
             external_event_id=None,
             barcode=None,
             sector_name=None,
@@ -209,7 +214,8 @@ class Ticket:
             venue=None,
             event=None,
             currency=None,
-            external_card_ref=None
+            external_card_ref=None,
+            additional_fields=None,
         )
 
     @classmethod
@@ -222,6 +228,7 @@ class Ticket:
             qr_code_url=None,
             session_date=None,
             title=None,
+            legacy_external_event_id=None,
             external_event_id=None,
             barcode=None,
             sector_name=None,
@@ -255,7 +262,8 @@ class Ticket:
             venue: Venue or str or int or None = None,
             event: Event or str or int or None = None,
             currency: Currency or None = None,
-            external_card_ref=None
+            external_card_ref=None,
+            additional_fields=None,
     ):
         ticket = Ticket(
             id=None,
@@ -265,6 +273,7 @@ class Ticket:
             qr_code_url=qr_code_url,
             session_date=session_date,
             title=title,
+            legacy_external_event_id=legacy_external_event_id,
             external_event_id=external_event_id,
             barcode=barcode,
             sector_name=sector_name,
@@ -301,7 +310,8 @@ class Ticket:
             venue=venue,
             event=event,
             currency=currency,
-            external_card_ref=external_card_ref
+            external_card_ref=external_card_ref,
+            additional_fields=additional_fields
         )
         if isinstance(user, (str, int)):
             user = User.placeholder(id=user)
@@ -364,14 +374,25 @@ class Ticket:
     def diff(self, other):
         differences = {}
         fields = (
-            'external_ticket_id', 'seat', 'qr_code_url', 'session_date', 'title', 'external_event_id',
-            'barcode', 'sector_name', 'venue_name', 'venue_room', 'client_name', 'premium', 'client_email',
-            'price', 'status', 'can_share', 'sharer_email', 'redeemed_at', 'redeemer_id', 'share_code',
+            'external_ticket_id', 'seat', 'qr_code_url', 'session_date', 'title', 'legacy_external_event_id',
+            'external_event_id', 'barcode', 'sector_name', 'venue_name', 'venue_room', 'client_name', 'premium',
+            'client_email', 'price', 'status', 'can_share', 'sharer_email', 'redeemed_at', 'redeemer_id', 'share_code',
             'redeemer_email', 'parent_ticket', 'shared_at', 'legal_long_text', 'legal_short_text', 'map_url',
             'map_image_url', 'ticket_integration', 'entrance', 'row', 'section', 'price_code', 'external_customer_ref',
-            'venue', 'event', 'event_date', 'currency', 'external_card_ref'
+            'venue', 'event', 'event_date', 'currency', 'external_card_ref', 'additional_fields'
         )
         for field in fields:
             if getattr(self, field) != getattr(other, field):
-                differences[field] = getattr(self, field)
+                if field == 'additional_fields' and getattr(other, field):
+                    if getattr(self, field):
+                        additional_fields = []
+                        for current in getattr(other, field):
+                            for new in getattr(self, field):
+                                if current['sort'] == new['sort']:
+                                    for key in current.keys():
+                                        current[key] = new[key]
+                            additional_fields.append(current)
+                        differences[field] = additional_fields
+                else:
+                    differences[field] = getattr(self, field)
         return differences
