@@ -49,6 +49,7 @@ from livestyled.models import (
     TicketAuth,
     TicketIntegration,
     User,
+    UserCohort,
     UserEmail,
     UserInfo,
     UserSSO,
@@ -104,6 +105,7 @@ from livestyled.schemas import (
     TicketAuthSchema,
     TicketIntegrationSchema,
     TicketSchema,
+    UserCohortSchema,
     UserCreateSchema,
     UserInfoSchema,
     UserSchema,
@@ -537,11 +539,14 @@ class LiveStyledResourceClient(LiveStyledAPIClient):
     def get_user_ssos(
             self,
             sub: str or None = None,
+            user_id: int or None = None,
     ) -> Generator[UserSSO, None, None]:
+        filters = {}
         if sub:
-            return self._get_resource_list(UserSSOSchema, filters={'sub': sub})
-        else:
-            return self._get_resource_list(UserSSOSchema)
+            filters['sub'] = sub
+        if user_id:
+            filters['user'] = user_id
+        return self._get_resource_list(UserSSOSchema, filters=filters)
 
     def get_user_sso(
             self,
@@ -727,6 +732,12 @@ class LiveStyledResourceClient(LiveStyledAPIClient):
         )
         return True
 
+    def get_user_cohort(
+            self,
+            id: int
+    ) -> UserCohort:
+        return self._get_resource_by_id(UserCohortSchema, id)
+
     # ---- MAGIC FIELDS
 
     def get_magic_field(
@@ -865,7 +876,7 @@ class LiveStyledResourceClient(LiveStyledAPIClient):
             filters['provider'] = provider
         try:
             device_token_data = self._api_get(
-                'devices/{}/device_tokens'.format(device.id),
+                'v4/devices/{}/device_tokens'.format(device.id),
                 params=filters
             )
         except HTTPError as http_error:
